@@ -18,7 +18,9 @@ module Rabbit
     extend Forwardable
 
     include GetText
-    
+
+    INTERNAL_DPI = 72.0
+
     def_delegators(:@frame, :icon, :icon=, :set_icon)
     def_delegators(:@frame, :icon_list, :icon_list=, :set_icon_list)
     def_delegators(:@frame, :update_title)
@@ -85,8 +87,8 @@ module Rabbit
     def_delegators(:@renderer, :display?, :printable?)
     def_delegators(:@renderer, :x_dpi, :y_dpi)
     
-    def_delegators(:@renderer, :white_outing?, :black_outing?)
-    def_delegators(:@renderer, :toggle_white_out, :toggle_black_out)
+    def_delegators(:@renderer, :whiteouting?, :blackouting?)
+    def_delegators(:@renderer, :toggle_whiteout, :toggle_blackout)
 
     def_delegators(:@renderer, :showing_comment_frame?, :showing_comment_view?)
     def_delegators(:@renderer, :toggle_comment_frame, :toggle_comment_view)
@@ -286,6 +288,7 @@ module Rabbit
     end
 
     def <<(slide)
+      slide.index = slides.size
       slides << slide
     end
 
@@ -374,6 +377,7 @@ module Rabbit
                                         @output_html,
                                         @output_index_html,
                                         @rss_base_uri)
+        generator.pdf_filename = filename if /\.pdf/i =~ filename.to_s
         generator.save
       end
     end
@@ -416,9 +420,10 @@ module Rabbit
     def move_to_next_if_can
       slide = current_slide
       if slide and !slide.last?
+        old_index = slide.drawing_index
         slide.move_to_next
         Action.update_status(self)
-        activate("Redraw")
+        @renderer.post_move_in_slide(old_index, slide.drawing_index)
       else
         move_to_next_slide_if_can
       end
@@ -431,9 +436,10 @@ module Rabbit
     def move_to_previous_if_can
       slide = current_slide
       if slide and !slide.first?
+        old_index = slide.drawing_index
         slide.move_to_previous
         Action.update_status(self)
-        activate("Redraw")
+        @renderer.post_move_in_slide(old_index, slide.drawing_index)
       else
         move_to_previous_slide_if_can
       end
@@ -720,9 +726,10 @@ module Rabbit
     end
 
     def move_to(index)
+      old_index = current_index
       set_current_index(index)
       Action.update_status(self)
-      @renderer.post_move(current_index)
+      @renderer.post_move(old_index, current_index)
     end
 
     def init_comment(comment_source, comment_encoding)
