@@ -11,7 +11,7 @@ module Rabbit
 
       attr_reader :elements
 
-      def_delegators(:@elements, :[], :empty?, :each, :first, :last)
+      def_delegators(:@elements, :empty?, :each, :first, :last)
       def_delegators(:@elements, :size, :length)
 
       def initialize(elems=[])
@@ -92,7 +92,8 @@ module Rabbit
         @elements.each do |element|
           x, y, w, h = element.draw(simulation)
         end
-        if @elements.last and @elements.last.inline_element?
+        last_element = @elements.last
+        if last_element and last_element.inline_element?
           container_height = height
           x = base_x
           y += container_height
@@ -232,6 +233,22 @@ module Rabbit
       def have_wait_tag?
         @elements.any? {|element| element.have_wait_tag?}
       end
+
+      def [](name_or_index)
+        if name_or_index.is_a?(Integer)
+          @elements[name_or_index]
+        else
+          super
+        end
+      end
+
+      def []=(name_or_index, value)
+        if name_or_index.is_a?(Integer)
+          @elements[name_or_index] = value
+        else
+          super
+        end
+      end
     end
   end
 end
