@@ -12,6 +12,7 @@ module Rabbit
       alias image_draw draw
       alias draw element_draw
 
+      attr_reader :filename
       attr_reader :caption
       attr_reader :normalized_width, :normalized_height
       attr_reader :relative_width, :relative_height
@@ -41,6 +42,7 @@ module Rabbit
             raise InvalidImageSizeError.new(filename, name, prop[name])
           end
         end
+        setup_draw_parameters(prop)
         resize(@width, @height)
       end
 
@@ -108,9 +110,21 @@ module Rabbit
       end
 
       private
+      def setup_draw_parameters(prop)
+        @draw_parameters = {}
+        @draw_parameters[:reflect] = {} if true_value?(prop["reflect"])
+        [:ratio, :alpha].each do |key|
+          name = "reflect_#{key}"
+          value = prop[name]
+          next unless value
+          @draw_parameters[:reflect] ||= {}
+          @draw_parameters[:reflect][key] = Float(value)
+        end
+      end
+
       def draw_image(canvas, x, y, w, h, simulation)
         unless simulation
-          image_draw(canvas, x, y)
+          image_draw(canvas, x, y, @draw_parameters)
         end
         [x, y + height, w, h - height]
       end
