@@ -21,6 +21,10 @@ module Rabbit
       def to_html(generator)
         "<div class=\"slide\">\n#{super}\n</div>"
       end
+
+      def hide_title?
+        self["hide-title"] == "true"
+      end
     end
 
     class HeadLine
@@ -33,6 +37,11 @@ module Rabbit
       def to_html(generator)
         "<h1>#{super}</h1>"
       end
+
+      def draw_elements(canvas, x, y, w, h, simulation)
+        return [x, y, w, h] if slide.hide_title?
+        super
+      end
     end
 
     class Body
