@@ -8,7 +8,7 @@ require "rabbit/gettext"
 
 module Rabbit
 
-  VERSION = "0.5.7"
+  VERSION = "0.6.1"
 
   TMP_DIR_NAME = ".tmp"
 
@@ -25,10 +25,6 @@ module Rabbit
     end
   end
 
-  add_gui_init_proc do
-    Gtk.init
-  end
-
   class Error < StandardError
     include GetText
   end
