@@ -1,4 +1,5 @@
 require "rabbit/renderer/display/drawing-area-primitive"
+require 'rabbit/renderer/display/menu'
 require "rabbit/renderer/display/progress"
 require "rabbit/renderer/display/mask"
 require "rabbit/renderer/display/search"
@@ -17,6 +18,7 @@ module Rabbit
       module DrawingAreaBase
         include DrawingAreaPrimitive
 
+        include Menu
         include Graffiti
         include Mask
         include Progress
@@ -34,33 +36,6 @@ module Rabbit
           super
         end
 
-        def attach_to(window)
-          super
-          init_menu
-          init_gesture_actions
-          @hbox = Gtk::HBox.new
-          @vbox = Gtk::VBox.new
-          @vbox.pack_start(@area, true, true, 0)
-          @hbox.pack_end(@vbox, true, true, 0)
-          @window.add(@hbox)
-          @hbox.show
-          @vbox.show
-          attach_menu
-          attach_key
-          set_configure_event
-        end
-
-        def detach
-          detach_key
-          detach_menu
-          unless @window.destroyed?
-            @window.remove(@hbox)
-            @window.signal_handler_disconnect(@configure_signal_id)
-          end
-          @window = @hbox = @vbox = nil
-          super
-        end
-
         def post_apply_theme
           if @need_reload_theme
             @need_reload_theme = false
@@ -71,7 +46,7 @@ module Rabbit
           end
         end
 
-        def post_move(index)
+        def post_move(old_index, index)
           update_title
           reset_adjustment
           clear_graffiti
@@ -220,15 +195,36 @@ module Rabbit
           end
         end
 
-        def toggle_white_out
+        def attach_to(window)
+          super
+
+          init_menu
+          init_gesture_actions
+          add_widget_to_window(@window)
+          widget.show
+          attach_menu(@window)
+          attach_key(@window)
+        end
+
+        def detach
+          detach_key(@window)
+          detach_menu(@window)
+          widget.hide
+          unless @window.destroyed?
+            remove_widget_from_window(@window)
+            @window.signal_handler_disconnect(@configure_signal_id)
+          end
+
+          super
+        end
+
+        def toggle_whiteout
           super
-          update_menu
           @area.queue_draw
         end
 
-        def toggle_black_out
+        def toggle_blackout
           super
-          update_menu
           @area.queue_draw
         end
 
@@ -241,8 +237,19 @@ module Rabbit
         end
 
         private
-        def update_title
-          @canvas.update_title(@canvas.slide_title)
+        def add_widget_to_window(window)
+          @hbox = Gtk::HBox.new
+          @vbox = Gtk::VBox.new
+          @vbox.pack_start(@area, true, true, 0)
+          @hbox.pack_end(@vbox, true, true, 0)
+          window.add(@hbox)
+          @hbox.show
+          @vbox.show
+        end
+
+        def remove_widget_from_window(window)
+          window.remove(@hbox)
+          @hbox = @vbox = nil
         end
 
         def init_drawing_area
@@ -259,7 +266,7 @@ module Rabbit
           set_scroll_event
         end
 
-        def realized(widget)
+        def mapped(widget)
           super
           @white = Gdk::GC.new(@drawable)
           @white.set_rgb_fg_color(Color.parse("white").to_gdk_color)
@@ -276,10 +283,10 @@ module Rabbit
         def exposed(widget, event)
           reload_source unless @caching
 
-          if @white_out
+          if whiteouting?
             @drawable.draw_rectangle(@white, true, 0, 0,
                                      original_width, original_height)
-          elsif @black_out
+          elsif blackouting?
             @drawable.draw_rectangle(@black, true, 0, 0,
                                      original_width, original_height)
           else
@@ -372,14 +379,6 @@ module Rabbit
           end
         end
 
-        def set_configure_event
-          id = @window.signal_connect("configure_event") do |widget, event|
-            configured(event.x, event.y, event.width, event.height)
-            false
-          end
-          @configure_signal_id = id
-        end
-
         def confirm_dialog(message)
           flags = Gtk::Dialog::MODAL | Gtk::Dialog::DESTROY_WITH_PARENT
           dialog_type = Gtk::MessageDialog::INFO
@@ -390,10 +389,6 @@ module Rabbit
           dialog.destroy
           result
         end
-
-        def call_hook_procs(procs, *args)
-          procs.any? {|proc| proc.call(*args)}
-        end
       end
     end
   end
