@@ -25,32 +25,16 @@ module Rabbit
 
         def attach_to(window)
           init_gl(@area)
-          @area.show
-          @window = window
+          super
         end
 
         def detach
           finalize_gl
-          @area.hide
-          @window = nil
+          super
         end
 
-        def width
-          if @drawable
-            @drawable.size[0]
-          end
-        end
-        alias original_width width
-
-        def height
-          if @drawable
-            @drawable.size[1]
-          end
-        end
-        alias original_height height
-
-        def redraw
-          @area.queue_draw
+        def widget
+          @area
         end
 
         def clear_slide
@@ -73,11 +57,15 @@ module Rabbit
 
         def post_apply_theme
           clear_compiled_slides
-          @area.queue_draw
+          queue_draw
         end
 
-        def post_move(index)
-          @area.queue_draw
+        def post_move(old_index, index)
+          queue_draw
+        end
+
+        def post_move_in_slide(old_index, index)
+          queue_draw
         end
 
         def pre_parse
@@ -91,7 +79,7 @@ module Rabbit
         end
 
         def post_toggle_index_mode
-          @area.queue_draw
+          queue_draw
         end
 
         def pre_to_pixbuf(slide_size)
@@ -113,21 +101,6 @@ module Rabbit
           restore_cursor(:index)
         end
 
-        def make_layout(text)
-          attrs, text = Pango.parse_markup(text)
-          layout = create_pango_layout(text)
-          layout.set_attributes(attrs)
-          layout
-        end
-
-        def create_pango_context
-          @area.create_pango_context
-        end
-
-        def create_pango_layout(text)
-          @area.create_pango_layout(text)
-        end
-
         def display?
           true
         end
@@ -158,6 +131,7 @@ module Rabbit
 
         def mapped(widget)
           @drawable = widget.window
+          prepare_renderer(@drawable)
         end
 
         def set_expose_event
@@ -177,8 +151,12 @@ module Rabbit
         def draw_current_slide
           slide = @canvas.current_slide
           if slide
-            compile_slide(slide) unless compiled_slide?(slide)
-            slide.draw(@canvas, false)
+            begin
+              compile_slide(slide) unless compiled_slide?(slide)
+              slide.draw(@canvas, false)
+            rescue
+              @canvas.logger.warn($!)
+            end
           end
         end
 
@@ -196,7 +174,6 @@ module Rabbit
         def reload_theme(&callback)
           callback ||= Utils.process_pending_events_proc
           @canvas.activate("ReloadTheme", &callback)
-          clear_compiled_slides
         end
 
         def clear_compiled_slide(slide=nil)
@@ -216,10 +193,6 @@ module Rabbit
           slide.draw(@canvas, true)
         end
 
-        def queue_draw
-          @area.queue_draw
-        end
-
         def grab
           Gtk.grab_add(@area)
           Gdk.pointer_grab(@area.window, false,
