@@ -84,25 +84,32 @@ module Rabbit
           pixbuf
         end
 
+        def prepare_renderer(drawable)
+        end
+
         def init_renderer(drawable)
-          @contexts ||= []
-          @context = drawable.create_cairo_context
-          @contexts.push(@context)
-          init_context
+          init_context(drawable.create_cairo_context)
         end
 
         def finish_renderer
-          @contexts.pop
-          @context.destroy if @context.respond_to?(:destroy)
-          @context = @contexts.pop
+          finish_context
         end
 
-        def init_context
+        def init_context(context)
+          @context = context
+          @contexts ||= []
+          @contexts.push(@context)
           set_line_width(1)
           @context.line_cap = ::Cairo::LINE_CAP_ROUND
           @context.line_join = ::Cairo::LINE_JOIN_ROUND
         end
 
+        def finish_context
+          @contexts.pop
+          @context.destroy if @context.respond_to?(:destroy)
+          @context = @contexts.last
+        end
+
         def to_gdk_rgb(color)
           make_color(color).to_gdk_rgb
         end
@@ -244,11 +251,24 @@ module Rabbit
 
         def draw_pixbuf(pixbuf, x, y, params={})
           x, y = from_screen(x, y)
+
+          draw_scaled_pixbuf = params[:draw_scaled_pixbuf]
+          width = (params[:width] || pixbuf.width).to_f
+          height = (params[:height] || pixbuf.height).to_f
+          if draw_scaled_pixbuf and
+              [width, height] != [pixbuf.width, pixbuf.height]
+            pixbuf = pixbuf.scale(width, height)
+          end
           @context.save do
             @context.translate(x, y)
+            unless draw_scaled_pixbuf
+              @context.scale(width / pixbuf.width, height / pixbuf.height)
+            end
             @context.set_source_pixbuf(pixbuf, 0, 0)
             @context.paint
           end
+
+          _draw_reflected_pixbuf(pixbuf, x, y, params[:reflect])
         end
 
         def rsvg_available?
@@ -262,8 +282,8 @@ module Rabbit
         def draw_rsvg_handle(handle, x, y, params={})
           x, y = from_screen(x, y)
           dim = handle.dimensions
-          width = (params["width"] || dim.width).to_f
-          height = (params["height"] || dim.height).to_f
+          width = (params[:width] || dim.width).to_f
+          height = (params[:height] || dim.height).to_f
           @context.save do
             @context.translate(x, y)
             @context.scale(width / dim.width, height / dim.height)
@@ -283,8 +303,8 @@ module Rabbit
         def draw_poppler_page(page, x, y, params={})
           x, y = from_screen(x, y)
           w, h = page.size
-          width = (params["width"] || w).to_f
-          height = (params["height"] || h).to_f
+          width = (params[:width] || w).to_f
+          height = (params[:height] || h).to_f
           @context.save do
             @context.translate(x, y)
             @context.scale(width / w, height / h)
@@ -388,6 +408,28 @@ module Rabbit
         def make_matrix(xx, xy, x0, yx, yy, y0)
           ::Cairo::Matrix.new(xx, yx, xy, yy, x0, y0)
         end
+
+        def _draw_reflected_pixbuf(pixbuf, x, y, params)
+          return unless params
+
+          params = {} if params == true
+          ratio = params[:ratio] || 0.3
+          start_alpha = params[:start_alpha] || 0.3
+
+          @context.save do
+            width = pixbuf.width
+            height = pixbuf.height
+            @context.translate(x, y + height * 2)
+            reflect_context(:x)
+            @context.set_source_pixbuf(pixbuf, 0, 0)
+            pattern = ::Cairo::LinearPattern.new(width * 0.5, 0,
+                                                 width * 0.5, height)
+            pattern.add_color_stop_rgba(0, 0, 0, 0, 0)
+            pattern.add_color_stop_rgba(1 - ratio, 0, 0, 0, 0)
+            pattern.add_color_stop_rgba(1, 0, 0, 0, start_alpha)
+            @context.mask(pattern)
+          end
+        end
       end
     end
   end
