@@ -15,8 +15,10 @@ module Rabbit
     module Print
       class Cairo
         include Engine::Cairo
+        alias_method :cairo_rsvg_available?, :rsvg_available?
+        alias_method :cairo_poppler_available?, :poppler_available?
         include Base
-        
+
         class << self
           def priority
             if (::Cairo::VERSION <=> [1, 2, 0]) >= 0
@@ -35,7 +37,7 @@ module Rabbit
 
         def pre_print(slide_size)
           super
-          init_context
+          init_context(create_context)
         end
 
         def post_print(canceled)
@@ -52,9 +54,12 @@ module Rabbit
         def post_apply_theme
         end
         
-        def post_move(index)
+        def post_move(old_index, index)
         end
         
+        def post_move_in_slide(old_index, index)
+        end
+
         def internal_draw_slide(slide, simulation)
           yield
           @context.show_page if !simulation and @show_page
@@ -70,6 +75,14 @@ module Rabbit
           draw_rectangle(true, x, y, w, h, @background)
         end
 
+        def rsvg_available?
+          cairo_rsvg_available?
+        end
+
+        def poppler_available?
+          cairo_poppler_available?
+        end
+
         private
         def init_paper
           @page_width = @paper_width || A4_HEIGHT
@@ -82,11 +95,6 @@ module Rabbit
           @background = make_color(@background_color)
         end
 
-        def init_context
-          @context = create_context
-          super
-        end
-
         def create_context(output=nil)
           surface = find_surface(filename, output)
           surface.set_fallback_resolution(@x_dpi, @y_dpi)
