@@ -258,6 +258,42 @@ module Rabbit
         end
       end
 
+      def normalized_width
+        (canvas.x_dpi / Canvas::INTERNAL_DPI) * NORMALIZED_WIDTH
+      end
+
+      def normalized_height
+        (canvas.y_dpi / Canvas::INTERNAL_DPI) * NORMALIZED_HEIGHT
+      end
+
+      def normalized_size(s)
+        ((s / canvas.width.to_f) * normalized_width).ceil
+      end
+
+      def normalized_x(sx)
+        ((sx / canvas.width.to_f) * normalized_width).ceil
+      end
+
+      def normalized_y(sy)
+        ((sy / canvas.height.to_f) * normalized_height).ceil
+      end
+
+      def screen_size(n)
+        ((canvas.width * n) / normalized_width).ceil
+      end
+
+      def screen_x(nx)
+        ((canvas.width * nx) / normalized_width).ceil
+      end
+
+      def screen_y(ny)
+        ((canvas.height * ny) / normalized_height).ceil
+      end
+
+      def [](name)
+        instance_variable_get("@#{name}")
+      end
+
       private
       def normalize_source(src)
         src.gsub(/(?=^|\W)@(very_)?huge_(script_)?font_size(?=$|\W)/) do |x|
@@ -462,38 +498,6 @@ module Rabbit
         end
       end
 
-      def normalized_width
-        (canvas.x_dpi / 72.0) * NORMALIZED_WIDTH
-      end
-
-      def normalized_height
-        (canvas.y_dpi / 72.0) * NORMALIZED_HEIGHT
-      end
-
-      def normalized_size(s)
-        ((s / canvas.width.to_f) * normalized_width).ceil
-      end
-
-      def normalized_x(sx)
-        ((sx / canvas.width.to_f) * normalized_width).ceil
-      end
-
-      def normalized_y(sy)
-        ((sy / canvas.height.to_f) * normalized_height).ceil
-      end
-
-      def screen_size(n)
-        ((canvas.width * n) / normalized_width).ceil
-      end
-
-      def screen_x(nx)
-        ((canvas.width * nx) / normalized_width).ceil
-      end
-
-      def screen_y(ny)
-        ((canvas.height * ny) / normalized_height).ceil
-      end
-
       def indent(*args, &block)
         split_targets(args) do |targets, args|
           targets.indent(*args, &block)
