@@ -1,6 +1,7 @@
 add_image_path("clear-blue-images")
 
 base_color = "#458cff"
+base_dark_color = "#0041ab"
 base_dark_background_color = "#e9ffff"
 base_background_color = "#ffffff"
 
@@ -24,7 +25,7 @@ set_progress_background(base_background_color)
 @default_block_quote_item1_mark_color = base_color
 @description_term_line_color = base_color
 
-@default_emphasis_color = base_color
+@default_emphasis_color = base_dark_color
 
 @preformatted_frame_color = base_color
 @preformatted_fill_color = base_background_color
@@ -80,7 +81,7 @@ end
 match(Slide, Body) do |bodies|
   bodies.vertical_centering = true
   bodies.each do |body|
-    next if body.elements.any? {|element| element.is_a?(Image)}
+    next if body.elements.all? {|element| element.is_a?(Image)}
     next if body.elements.any? {|element| element.is_a?(BlockQuote)}
     next if body.elements.any? {|element| element.is_a?(PreformattedBlock)}
     next if body.elements.any? {|element| element.is_a?(Table)}
@@ -89,7 +90,7 @@ match(Slide, Body) do |bodies|
   end
 end
 
-@slide_logo_image = "clear-blue-headline-background.png"
+@slide_logo_image ||= "clear-blue-headline-background.png"
 include_theme("slide-logo")
 
 @icon_images = ["clear-blue-icon.png"]
