@@ -15,6 +15,13 @@ set_graffiti_color("red")
 @title_logo_position = :left
 include_theme("title-logo")
 
+@ruby_gnome2_color ||= "#003399"
+@ruby_gnome2_emphasis_color ||= "#006600"
+@ruby_gnome2_line_color ||= "#ff9999"
+@ruby_gnome2_frame_color ||= "#3399cc"
+@ruby_gnome2_fill_color ||= "#ddeeff"
+@ruby_gnome2_item_mark_color ||= "black"
+
 include_theme("ruby-gnome2-icon")
 include_theme("ruby-gnome2-slide")
 include_theme("ruby-gnome2-headline")
@@ -52,5 +59,3 @@ match(Slide) do |slides|
     end
   end
 end
-
-include_theme("windows-adjust")
