@@ -1,8 +1,8 @@
 ;;; -*- mode: Emacs-Lisp; indent-tabs-mode: nil -*-
 ;;; rabbit-mode.el
 ;;  Emacs major mode for Rabbit
-;;; Copyright (c) 2006 Atsushi TAKEDA <tkdats@kono.cis.iwate-u.ac.jp>
-;;; $Date: 2006-09-07 15:44:54 +0900 (木, 07  9月 2006) $
+;;; Copyright (c) 2006 - 2008 Atsushi TAKEDA <tkdats@kono.cis.iwate-u.ac.jp>
+;;; $Id: rabbit-mode.el 1063 2008-03-01 08:40:07Z kou $
 
 (require 'cl)
 (require 'rd-mode)
@@ -66,11 +66,12 @@
     ("normalized")
     ("pixel")))
 
+(defvar rabbit-default-image-size-unit
+  "relative")
+
 (defvar rabbit-image-size-unit-history nil)
 
 (define-derived-mode rabbit-mode rd-mode "Rabbit"
-  (setq-default rabbit-running nil)
-  (make-variable-buffer-local 'rabbit-running)
   (setq comment-start "#")
   (make-local-variable 'font-lock-defaults)
   (setq font-lock-defaults '((rabbit-font-lock-keywords) t nil))
@@ -87,12 +88,10 @@
   (let ((filename (rabbit-buffer-filename))
 	(outbuf (rabbit-output-buffer)))
     (set-buffer outbuf)
-    (if rabbit-running
-	(error "Rabbit is already running.")
+    (if (get-buffer-process outbuf)
+        (error "Rabbit is already running")
       (progn
-	(setq rabbit-running t)
 	(start-process "Rabbit" outbuf rabbit-command filename)
-	(set-process-sentinel (get-buffer-process outbuf) 'rabbit-sentinel)
         (if (one-window-p)
             (set-window-buffer (split-window) outbuf)
           (set-window-buffer (previous-window) outbuf))))))
@@ -119,6 +118,13 @@
   (interactive "fimage file: ")
   (rabbit-insert-image-template-real file))
 
+(defun rabbit-insert-items ()
+  (interactive)
+  (let ((item (read-from-minibuffer "item: ")))
+    (unless (string-equal item "")
+      (insert (rabbit-block-indent (concat "* " item "\n")))
+      (rabbit-insert-items))))
+
 ;;; slide functions
 
 (defun rabbit-insert-slide (slide-title)
@@ -127,10 +133,22 @@
   (insert (concat "= " slide-title "\n\n")))
 
 (defun rabbit-delete-slide ()
-  "delete a slide that cursor is on."
+  "delete a current slide."
   (interactive)
   (rabbit-fancall-with-current-point 'delete-region))
 
+(defun rabbit-copy-slide ()
+  "copy a current slide."
+  (interactive)
+  (rabbit-fancall-with-current-point 'kill-ring-save))
+
+(defun rabbit-duplicate-slide ()
+  "copy a current slide and yank it as next slide."
+  (interactive)
+  (rabbit-copy-slide)
+  (rabbit-next-slide)
+  (yank))
+
 ;;; move functions
 
 (defun rabbit-next-slide ()
@@ -180,7 +198,7 @@
 (defun rabbit-metadata-string-template (metadata value)
   (concat ": " metadata "\n"
           (rabbit-block-indent " ") value "\n"))
-    
+
 (defun rabbit-read-property (key)
   "read `key' value from minibuf and return string as \"key = value\"
 format if value is specified, otherwise return \"\"."
@@ -205,11 +223,7 @@ format if value is specified, otherwise return \"\"."
 (defun rabbit-buffer-filename ()
   "return file name relating current buffer."
   (or (buffer-file-name)
-      (error "This buffer is empty buffer.")))
-
-(defun rabbit-sentinel (proc state)
-  (set-buffer (process-buffer proc))
-  (setq rabbit-running nil))
+      (error "This buffer is empty buffer")))
 
 (defun rabbit-output-buffer ()
   "return buffer for rabbit output."
@@ -219,16 +233,13 @@ format if value is specified, otherwise return \"\"."
 	 (buf (get-buffer-create bufname)))
     buf))
 
-(defun rabbit-default-image-size-unit ()
-  (caar rabbit-image-size-unit-table))
-
 (defun rabbit-read-size-unit ()
   "read what unit use for image size."
   (completing-read "image size unit: "
 		   rabbit-image-size-unit-table
                    nil t nil
                    'rabbit-image-size-unit-history
-                   (rabbit-default-image-size-unit)))
+                   rabbit-default-image-size-unit))
 
 (defun rabbit-filter (predicate lst)
   (let ((result '()))
@@ -260,7 +271,7 @@ format if value is specified, otherwise return \"\"."
                                             (file-relative-name filename)))
               ,(rabbit-read-block-property "caption")
               ,@(rabbit-read-size-value
-                 (or unit (rabbit-default-image-size-unit))))
+                 (or unit rabbit-default-image-size-unit)))
             "\n")
            "\n")))
 
